<?php
/**
 * Sample code for the CancelPickupRequest Canada Post service.
 * 
 * The CancelPickupRequest service cancels (deletes) an existing pickup request.
 * 
 * This sample is configured to access the Developer Program sandbox environment. 
 * Use your development key username and password for the web service credentials.
 * 
 */

// Your username and password are imported from the following file
// CPCWS_Pickup_PHP_Samples\REST\pickup\user.ini
$userProperties = parse_ini_file(realpath(dirname($_SERVER['SCRIPT_FILENAME'])) . '/../user.ini');

$username = $userProperties['username']; 
$password = $userProperties['password'];
$customer = $userProperties['customerNumber'];

$requestId = '0074698052';
$effectivDate = '2015-03-21';

// REST URI
$service_url = 'https://stg30.soa-gw.canadapost.ca/enab/' . $customer . '/pickuprequest/'. $requestId;

$curl = curl_init($service_url); // Create REST Request
curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, true);
curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, 2);
curl_setopt($curl, CURLOPT_CAINFO, realpath(dirname($_SERVER['SCRIPT_FILENAME'])) . '/../../../third-party/cert/cacert.pem'); // Signer Certificate in PEM format
curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'DELETE');
curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
curl_setopt($curl, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
curl_setopt($curl, CURLOPT_USERPWD, $username . ':' . $password);
$curl_response = curl_exec($curl); // Execute REST Request
if(curl_errno($curl)){
	echo 'Curl error: ' . curl_error($curl) . "\n";
}

echo 'HTTP Response Status: ' . curl_getinfo($curl,CURLINFO_HTTP_CODE) . "\n";

if ( curl_getinfo($curl,CURLINFO_HTTP_CODE) == 200 ) {
	// If server returns HTTP status code 200 then delete is successful.
	echo 'Pickup Request successfully cancelled.' . "\n";
} else {
	// Example of using SimpleXML to parse xml error response
	libxml_use_internal_errors(true);
	$xml = simplexml_load_string('<root>' . preg_replace('/<\?xml.*\?>/','',$curl_response) . '</root>');
	if (!$xml) {
		echo 'Failed loading XML' . "\n";
		echo $curl_response . "\n";
		foreach(libxml_get_errors() as $error) {
			echo "\t" . $error->message;
		}
	}
	if ($xml->{'messages'} ) {					
		$messages = $xml->{'messages'}->children('http://www.canadapost.ca/ws/messages');		
		foreach ( $messages as $message ) {
			echo 'Error Code: ' . $message->code . "\n";
			echo 'Error Msg: ' . $message->description . "\n\n";
		}
	}
}

curl_close($curl);
?>

